@@ -24,10 +24,10 @@
 
 
 #define XCLASS_MAJOR_VERSION  "0"
-#define XCLASS_MINOR_VERSION  "8"
-#define XCLASS_PATCH_LEVEL    "3"
-#define XCLASS_VERSION        "0.8.3"
-#define XCLASS_RELEASE_DATE   "5-Jul-2004"
+#define XCLASS_MINOR_VERSION  "9"
+#define XCLASS_PATCH_LEVEL    "1"
+#define XCLASS_VERSION        "0.9.1"
+#define XCLASS_RELEASE_DATE   "16-Sep-2004"
 
 
 #endif  // __VERSION_H
