@@ -33,6 +33,13 @@
 #include <xclass/OXFileDialog.h>
 #include <xclass/OResourcePool.h>
 
+#include "icons/tb-uplevel.xpm"
+#include "icons/tb-newfolder.xpm"
+#include "icons/tb-list.xpm"
+#include "icons/tb-details.xpm"
+#include "icons/tb-addfavor.xpm"
+#include "icons/tb-favor.xpm"
+
 
 #define IDF_CDUP        0
 #define IDF_NEW_FOLDER  1
@@ -59,6 +66,7 @@ OFileInfo::OFileInfo() {
   filename = NULL;
   ini_dir = NULL;
   file_types = NULL;
+  file_types_index = 0;
 }
   
 OFileInfo::~OFileInfo() { 
@@ -158,13 +166,26 @@ void OXFileDialog::_FileDialog(int dlg_type, OFileInfo *file_info) {
   _tree_lb = new OXFileSystemDDListBox(_htop, IDF_FSLB);
   _tree_lb->Associate(this);
 
+  // try user-defined toolbar pixmaps first...
+
   pcdup = _client->GetPicture("tb-uplevel.xpm");
   pnewf = _client->GetPicture("tb-newfolder.xpm");
   plist = _client->GetPicture("tb-list.xpm");
   pdetails = _client->GetPicture("tb-details.xpm");
 
-  if (!(plist && pnewf && plist && pdetails))
-    FatalError("OXFileDialog: missing toolbar pixmap(s).\n");
+  // use our default pixmaps for the missing ones...
+
+  if (!pcdup)
+    pcdup = _client->GetPicture("tb-uplevel.xpm", XCP_tb_uplevel_xpm);
+  if (!pnewf)
+    pnewf = _client->GetPicture("tb-newfolder.xpm", XCP_tb_newfolder_xpm);
+  if (!plist)
+    plist = _client->GetPicture("tb-list.xpm", XCP_tb_list_xpm);
+  if (!pdetails)
+    pdetails = _client->GetPicture("tb-details.xpm", XCP_tb_details_xpm);
+
+  if (!(pcdup && pnewf && plist && pdetails))
+    FatalError("OXFileDialog: missing toolbar pixmap(s).");
 
   _cdup = new OXPictureButton(_htop, pcdup, IDF_CDUP);
   _newf = new OXPictureButton(_htop, pnewf, IDF_NEW_FOLDER);
@@ -190,8 +211,13 @@ void OXFileDialog::_FileDialog(int dlg_type, OFileInfo *file_info) {
     paddfavor = _client->GetPicture("tb-addfavor.xpm");
     pfavor = _client->GetPicture("tb-favor.xpm");
 
+    if (!paddfavor)
+      paddfavor = _client->GetPicture("tb-addfavor.xpm", XCP_tb_addfavor_xpm);
+    if (!pfavor)
+      pfavor = _client->GetPicture("tb-favor.xpm", XCP_tb_favor_xpm);
+
     if (!(paddfavor && pfavor))
-      FatalError("OXFileDialog: missing toolbar pixmap(s).\n");
+      FatalError("OXFileDialog: missing toolbar pixmap(s).");
 
     const char *userRoot = _client->GetResourcePool()->GetUserRoot();
     _favorDir = new char[strlen(userRoot) + 12];
@@ -295,13 +321,20 @@ void OXFileDialog::_FileDialog(int dlg_type, OFileInfo *file_info) {
   if (_file_info->file_types) {
     for (i = 0; _file_info->file_types[i] != NULL; i += 2)
       _ftypes->AddEntry(new OString(_file_info->file_types[i]), i);
-    _ftypes->Select(0);
+
+    int index = _file_info->file_types_index;
+    if (index < 0)
+      index = 0;
+    else if (index >= i / 2)
+      index = i / 2;
+
+    _ftypes->Select(index);
 
     _fname->Clear();
     switch (_dlg_type & TYPE_MASK) {
       case FDLG_OPEN:
       case FDLG_BROWSE:
-        _fname->AddText(0, _file_info->file_types[1]);
+        _fname->AddText(0, _file_info->file_types[2 * index + 1]);
         break;
 
       case FDLG_SAVE:
@@ -311,7 +344,7 @@ void OXFileDialog::_FileDialog(int dlg_type, OFileInfo *file_info) {
         }
         break;
     }
-    _fv->SetFileFilter(_file_info->file_types[1], False);
+    _fv->SetFileFilter(_file_info->file_types[2 * index + 1], False);
   }
 
   _hftype->AddFrame(_lftypes, _lhl);
@@ -510,6 +543,7 @@ int OXFileDialog::ProcessMessage(OMessage *msg) {
             _fname->Clear();
             _fname->AddText(0, _file_info->file_types[te->ID()+1]);
           }
+          _file_info->file_types_index = te->ID();
           _fv->SetFileFilter(_file_info->file_types[te->ID()+1]);
           _client->NeedRedraw(_fname);
         }
