@@ -110,6 +110,8 @@ OXTextEdit::OXTextEdit(const OXWindow *p, int w, int h, int id,
   _cursorPos = _textIndex = OPosition(0, 0);
   _cursorLastX = 0;
 
+  _autoUpdate = True;
+
   _tabWidth = TAB_WIDTH;
   _blinkTime = 250;
 
@@ -225,6 +227,8 @@ int OXTextEdit::HandleButton(XButtonEvent *event) {
   int n;
   OTextLine *eventItem = NULL;
 
+  if (OXView::HandleButton(event)) return True;  // wheel-mouse scroll
+
   OPosition eventPos = ToVirtual(OPosition(event->x, event->y));
 
   eventPos = AdjustCoord(eventPos);
@@ -301,6 +305,8 @@ int OXTextEdit::HandleDoubleClick(XButtonEvent *event) {
   int n;
   OTextLine *eventItem = NULL;
 
+  if (event->button != Button1) return False;
+
   OPosition eventPos = ToVirtual(OPosition(event->x, event->y));
 
   eventPos = AdjustCoord(eventPos);
@@ -377,6 +383,8 @@ int OXTextEdit::HandleTripleClick(XButtonEvent *event) {
   int n;
   OTextLine *eventItem = NULL;
 
+  if (event->button != Button1) return False;
+
   OPosition eventPos = ToVirtual(OPosition(event->x, event->y));
 
   eventPos = AdjustCoord(eventPos);
@@ -426,10 +434,10 @@ int OXTextEdit::HandleMotion(XMotionEvent *event) {
 //   Ctrl-Ins, Shift-Ins, Backspace, Delete, Shift-Delete
 
 int OXTextEdit::HandleKey(XKeyEvent *event) {
-  char input[2] = { 0, 0 };
-  int  charcount;
+  char input[4] = { 0, 0, 0, 0 };
+  int  charcount, update = _autoUpdate;
   KeySym keysym;
-  XComposeStatus compose = { NULL, 0 };
+  static XComposeStatus compose = { NULL, 0 };
   OTextLine *line;
 
   if (_items.size() == 0) AddLine("");  //return True;
@@ -447,6 +455,8 @@ int OXTextEdit::HandleKey(XKeyEvent *event) {
       }
     }
 
+    _autoUpdate = True;
+
     switch (keysym) {
       case XK_Left:
         if (_readOnly) {
@@ -578,8 +588,9 @@ int OXTextEdit::HandleKey(XKeyEvent *event) {
         }
         break;
 
-      case XK_Tab:
       default:
+        if ((charcount == 1) && (event->state & Mod1Mask)) *input |= 0x80;
+      case XK_Tab:
         if (_readOnly || charcount == 0) break;
         if (_hasSelection) {
           DeleteSelection();
@@ -635,6 +646,8 @@ int OXTextEdit::HandleKey(XKeyEvent *event) {
 
   }
 
+  _autoUpdate = update;
+
   return True;
 }
 
@@ -910,10 +923,12 @@ void OXTextEdit::InsertText(const char *string, int len) {
   _changed = True;
   _UpdateCursor(_textIndex);
   _cursorLastX = _cursorPos.x;
-  CalcMaxItemSize();
-  _needItemLayout = True;
-  Layout();
-  NeedRedraw(ORectangle(_visibleStart, _canvas->GetSize()));
+  if (_autoUpdate) {
+    CalcMaxItemSize();
+    _needItemLayout = True;
+    Layout();
+    NeedRedraw(ORectangle(_visibleStart, _canvas->GetSize()));
+  }
 }
 
 // Return the whole contents of the text widget in a single OString object.
@@ -1484,14 +1499,16 @@ void OXTextEdit::SplitLine(int lnum, int charpos) {
   OTextLine *newline = new OTextLine(this, tmp);
 
   if (lnum < _items.size()-1)
-    _items.insert(&_items[lnum+1], newline);
+    _items.insert(_items.begin() + lnum + 1, newline); // .insert(&_items[lnum+1], newline);
   else
     _items.push_back(newline);
 
   _changed = True;
-  NeedRedraw(ORectangle(line->GetPosition(), _canvas->GetSize()));
-  CalcMaxItemSize();
-  Layout();
+  if (_autoUpdate) {
+    NeedRedraw(ORectangle(line->GetPosition(), _canvas->GetSize()));
+    CalcMaxItemSize();
+    Layout();
+  }
 }
 
 // Join the specified line and the next into a new single one.
@@ -1504,10 +1521,12 @@ void OXTextEdit::JoinLine(int lnum) {
     line->Append(((OTextLine *) _items[lnum+1])->GetString());
     line->Resize(line->GetDefaultSize());
     delete _items[lnum+1];
-    _items.erase(&_items[lnum+1]);
+    _items.erase(_items.begin() + lnum + 1); // .erase(&_items[lnum+1]);
     _changed = True;
-    Layout();
-    NeedRedraw(ORectangle(line->GetPosition(), _canvas->GetSize()));
+    if (_autoUpdate) {
+      Layout();
+      NeedRedraw(ORectangle(line->GetPosition(), _canvas->GetSize()));
+    }
   }
 }
 
@@ -1521,7 +1540,7 @@ void OXTextEdit::DeleteChar(int lnum, int charpos) {
     line->RemoveChar(charpos);
     line->Resize(line->GetDefaultSize());
     _changed = True;
-    _CheckLayout(line);
+    if (_autoUpdate) _CheckLayout(line);
   } else if (lnum < _items.size()-1) {
     JoinLine(lnum);
   }
@@ -1554,7 +1573,7 @@ void OXTextEdit::DeleteSelection() {
       if ((charStart == 0) && (charEnd == line->GetTextLength())
           && (i < _items.size()-1) && _items[i+1]->IsSelected()) {
         delete _items[i];  // delete line;
-        _items.erase(&_items[i]);
+        _items.erase(_items.begin() + i);   // .erase(&_items[i]);
         --i;
       } else {
         line->RemoveText(charStart, charEnd - charStart);
@@ -1581,8 +1600,6 @@ void OXTextEdit::DeleteSelection() {
 
 //----------------------------------------------------------------------
 
-// The following 3 routines *really* need a serious rework...
-
 void OXTextEdit::SelectToPos(OPosition mousePos) {
   OTextLine *item;
   OPosition itemPos;
@@ -1732,6 +1749,20 @@ void OXTextEdit::UnSelectAll() {
   }
 }
 
+void OXTextEdit::AutoUpdate(int onoff) {
+  if (_autoUpdate != onoff) {
+    _autoUpdate = onoff;
+    if (_autoUpdate) {
+      _UpdateCursor(_textIndex);
+      _cursorLastX = _cursorPos.x;
+      CalcMaxItemSize();
+      _needItemLayout = True;
+      Layout();
+      NeedRedraw(ORectangle(_visibleStart, _canvas->GetSize()));
+    }
+  }
+}
+
 
 //----------------------------------------------------------------------
 
